/******************************************
	PURPOSE:	Tutorial on external interrupt use at the example of the touch sensor pad
	Created by      Rudy Schlaf for www.makecourse.com
	DATE:		3/2014
*******************************************/

#define interruptNumber 0 //if we use pin 2 for the external interrupt, we need to attach  interrupt number 0
                          //pin 3 would require interrupt number 1
                          
#define TouchPadPin 2		//connect touch sensor output (pin "S") to D2 (and pin "G" to GND and pin "V" to 5V)
#define LED 13                  //we use the built in LED to show a touch event

volatile byte TouchPadEventFlag;//all variables that are changed within an ISR need to be dimensioned as 'volatile'
                                //this variable will be used to tell the main loop that an interrupt event occurred.


void setup()
{
  pinMode(LED, OUTPUT);//define the built in LED pin as output
  pinMode(TouchPadPin, INPUT);//define the interrupt pin as an input
  Serial.begin(9600);//start serial communication
  attachInterrupt(interruptNumber,InterruptServiceRoutine, CHANGE);//CHANGE defines that the ISR is called when the voltage on the pin changes in either direction
              //we are using CHANGE and not LOW to 'debounce' the pad. Using LOW would result in a continuous reading of the touch event until your finger
              //is removed from the pad
}
 
void loop()
{
  if (TouchPadEventFlag==1)
  {
    Serial.println("Pad was touched");
    TouchPadEventFlag=0;//reset the flag for the next interrupt
  }

}

void InterruptServiceRoutine()//ISRs need to be void and have no parameters.
{
  
if(digitalRead(TouchPadPin)==HIGH)	//when nothing touches the pad the output is HIGH
  {
    digitalWrite(LED, LOW);             //LED is off
  }
   
  if(digitalRead(TouchPadPin)==LOW)	//touching the pad causes the output to go LOW
  {
    digitalWrite(LED, HIGH);//turn the LED on
    TouchPadEventFlag=1;//set the flag to tell the main loop that a touch event occurred.
  }
  
}
